# DALL-E FOR FREE :heart:

 

## HOW TO USE

1. INSTALL DALLE43: `pip install -U dalle43`


2. GENERATE AN IMAGE 

```python
import dalle43.dalle43 as DALL_E

DALL_E.generate('the milky way') # returns the image path, e.g. 'C:\\Users\\0ut0flin3\\Pictures\\generated_images\\892348097.jpg'  

```

You can also use show() to show the image:

```python
img = DALL_E.generate('the milky way') # returns the image path, e.g. 'C:\\Users\\0ut0flin3\\Pictures\\generated_images\\892348097.jpg'  

DALL_E.show(img)
```

3. Enjoy! :heart:


![Screenshot from 2023-03-20 02-32-03](https://user-images.githubusercontent.com/114559605/226227544-66d2e956-8bd6-43d5-8397-41e720674b7a.png)
